@echo off
rem ********************************************************************************
rem *
rem * CFGRAID.BAT
rem *
rem * This file controls the management of RAID configuration of any supported RAID
rem * adapters found in the system.
rem *
rem * The CFG_RD environment variable defined and set in usrvars.bat controls
rem * whether this batch file is run or not.
rem *
rem * This batch file is called by runinst.bat.
rem *
rem ********************************************************************************

rem * initially, our state is that no RAID configurations have been done.
SET CFG_DONE=N

rem * Initialize our state that no RAID errors encountered.
SET RERS=N

rem ********************************************************************************
rem * See if user set the %RD_STUB% var in UsrVars is populated. If not,
rem * then it is impossible to do RAID config, so fail.
rem ********************************************************************************

if "%RD_STUB%"  == ""  if %CFG_RD%==Y echo NO RD STUB AND CFG RD = Y
if "%RD_STUB%"  == ""  if %CFG_RD%==Y goto RAIDFAIL
if "%RD_STUB%"  == ""  if %CFG_RD%==y goto RAIDFAIL


rem ********************************************************************************
rem * Determine if there are any IBM ServeRAID adapters found - max=16
rem ********************************************************************************
set NM_SR=0

call hwdet.bat

rem ********************************************************************************
rem * Attempt to load DOS device driver for ServeRAID since one or more is found
rem ********************************************************************************
if not %NM_SR%==0 call loadraid.bat

if %RD_RFD%==N goto CFG
if %RD_RFD%==n goto CFG

:CLN
call raidcln.bat

rem ********************************************************************************
rem * Check for errors from RAIDCLN
rem ********************************************************************************
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem *
rem * The errorlevel here controls the installation process.
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR

if %CFG_RD%==N  goto END
if %CFG_RD%==n  goto END


:CFG

for %%i in (1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16) do call raidmgr.bat %%i

rem ********************************************************************************
rem * Check for errors from RAIDMGR
rem *******************************************************************************

savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem *
rem * The errorlevel here controls the installation process.
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR

rem ********************************************************************************
rem * Don't require a reboot of the system, unless there was a configuration actually
rem * done.  If no configuration, skip to END.
rem ********************************************************************************

if %CFG_DONE%==F goto CFGFAIL
if %CFG_DONE%==E goto ERROR

rem ********************************************************************************
rem * end of ServeRAID "E" config section
rem ********************************************************************************


:RAIDSAVE
rem ********************************************************************************
rem * Write information to persistent storage that will identify what installation
rem * steps have been completed so far, and control where processing resumes after
rem * the reboot.
rem ********************************************************************************
echo.
echo RAID configuration Complete!  Saving status and rebooting server if necessary.

rem ********************************************************************************
rem * If not doing a standard Toolkit installation, jump
rem ********************************************************************************
if %DPLY_TYPE%==4 goto ALTSTAT0
if %DPLY_TYPE%==5 goto RAIDBOOT

savestat.exe /set2=50 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
if not errorlevel 255 goto RAIDBOOT
echo An error occurred during writing to persistent storage.
echo.
goto ERROR


:RAIDBOOT
rem ********************************************************************************
rem * A configuration was done, so we need to reboot the system before continuing to
rem * process.
rem ********************************************************************************
if %CFG_DONE%==Y goto REBOOT
goto END

:REBOOT
sleep 15
reboot.com

goto END

:RAIDFAIL
rem ********************************************************************************
rem * Problem in usrvars.bat.
rem ********************************************************************************
echo Unable to attempt RAID configuration. CFG_RD is set to %CFG_RD% in
echo usrvars.bat but RD_STUB was not set in usrvars. Edit usrvars.bat.
echo set RD_STUB properly, and restart this process.
goto ERROR


:CFGFAIL
rem ********************************************************************************
rem * Configuration failures
rem ********************************************************************************
echo.
echo All attempts at configuring any supported RAID controller have failed!
echo Verify the hardware information provided in the RAID configuration files
echo is valid for the system being configured.
echo.
goto ERROR


:ERROR
rem ********************************************************************************
rem * Hit an error in this batch file.
rem ********************************************************************************
echo Encountered an error and stopped processing in "cfgraid.bat".

if %DPLY_TYPE%==4 goto ALTSTAT1

savestat.exe /set2=251 > nul
goto END


:ADSSTAT
rem ********************************************************************************
rem * ADS jump
rem ********************************************************************************
goto END


:ALTSTAT0
rem ********************************************************************************
rem * Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Good

rem * Did we encounter any errors during the processing that we ignored?
if %RERS%==Y togo IGERRS

%TKDRV%\logevent.exe -c:0 -l:1 -ss:"CFGRAID: Completed successfully."
goto END

:IGERRS
%TKDRV%\logevent.exe -c:0 -l:1 -ss:"CFGRAID: Completed successfully by ignoring errors."

rem Reset to root of Toolkit drive
%TKDRV%
cd \

goto END


:ALTSTAT1
rem ********************************************************************************
rem * Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Error
%TKDRV%\logevent.exe -c:251 -l:3 -ss:"CFGRAID:  Encountered an error."

rem Reset to root of Toolkit drive
%TKDRV%
cd \

rem Reset persistent storage
savestat.exe /reset > nul
goto END


:END
set CFG_DONE=
set RERS=
set NM_SR=
set NM_TT=
set NM_EA=
set NM_ES=
set NM_IS=
set NM_ID=
